@@ -1,7 +1,6 @@
 """Django page CMS urls module."""
 
-from django.conf.urls.defaults import url, include, patterns
-from django.conf.urls.defaults import handler404, handler500
+from django.conf.urls import url, patterns
 from basic_cms.views import details
 from basic_cms import settings
 
